@@ -33,9 +33,7 @@
 #include <konqtabs.h>
 #include <konqframevisitor.h>
 #include <konqsessionmanager.h>
-#include <kstandarddirs.h>
 #include <kconfiggroup.h>
-#include <ktempdir.h>
 #include <kio/job.h>
 #include <ksycoca.h>
 
@@ -215,7 +213,7 @@ void ViewMgrTest::initTestCase()
     if (needsUpdate) {
         profile->sync();
         // kbuildsycoca is the one reading mimeapps.list, so we need to run it now
-        QProcess::execute(KStandardDirs::findExe(KBUILDSYCOCA_EXENAME));
+        QProcess::execute(QStandardPaths::findExecutable(KBUILDSYCOCA_EXENAME));
     }
 }
 
@@ -505,7 +503,7 @@ static void checkSecondWindowHasOneTab(bool fromPopup) // and delete it.
     QTRY_COMPARE(KMainWindow::memberList().count(), 2);
     QScopedPointer<KonqMainWindow> newWindow(qobject_cast<KonqMainWindow *>(KMainWindow::memberList().last()));
     QVERIFY(newWindow.data());
-    QCOMPARE(DebugFrameVisitor::inspect(newWindow.data()), QString("MT[F].")); // mainWindow, tab widget, one tab
+    QTRY_COMPARE(DebugFrameVisitor::inspect(newWindow.data()), QString("MT[F].")); // mainWindow, tab widget, one tab
     QTabWidget *tabWidget = newWindow->findChild<QTabWidget *>();
     QVERIFY(tabWidget);
     // The location bar shouldn't get focus (#208821)
@@ -527,8 +525,7 @@ void ViewMgrTest::testPopupNewWindow() // RMB, "Open new window"
     KFileItem item(QUrl(QStringLiteral("data:text/html, hello")), QStringLiteral("text/html"), S_IFREG);
     mainWindow.prepareForPopupMenu(KFileItemList() << item, KParts::OpenUrlArguments(), KParts::BrowserArguments());
     QMetaObject::invokeMethod(&mainWindow, "slotPopupNewWindow");
-    QTest::qWait(100);
-    QCOMPARE(DebugFrameVisitor::inspect(&mainWindow), QString("MT[F].")); // mainWindow, tab widget, one tab
+    QTRY_COMPARE(DebugFrameVisitor::inspect(&mainWindow), QString("MT[F].")); // mainWindow, tab widget, one tab
     QVERIFY(KMainWindow::memberList().last() != &mainWindow);
     checkSecondWindowHasOneTab(true);
 }
