@@ -124,41 +124,41 @@ public:
                               bool selected = false, bool current = false);
 
     // getters
-    QString  text(int) const Q_DECL_OVERRIDE;
-    QPixmap  pixmap(int) const Q_DECL_OVERRIDE;
-    Position position(int) const Q_DECL_OVERRIDE;
-    int      maxLines(int) const Q_DECL_OVERRIDE;
-    int      fieldCount() const Q_DECL_OVERRIDE
+    QString  text(int) const override;
+    QPixmap  pixmap(int) const override;
+    Position position(int) const override;
+    int      maxLines(int) const override;
+    int      fieldCount() const override
     {
         return _field.size();
     }
 
-    QColor   backColor() const Q_DECL_OVERRIDE
+    QColor   backColor() const override
     {
         return _backColor;
     }
-    bool selected() const Q_DECL_OVERRIDE
+    bool selected() const override
     {
         return _selected;
     }
-    bool current() const Q_DECL_OVERRIDE
+    bool current() const override
     {
         return _current;
     }
-    bool shaded() const Q_DECL_OVERRIDE
+    bool shaded() const override
     {
         return _shaded;
     }
-    bool rotated() const Q_DECL_OVERRIDE
+    bool rotated() const override
     {
         return _rotated;
     }
-    bool drawFrame() const Q_DECL_OVERRIDE
+    bool drawFrame() const override
     {
         return _drawFrame;
     }
 
-    const QFont &font() const Q_DECL_OVERRIDE;
+    const QFont &font() const override;
 
     // attribute setters
     void setField(int f, const QString &t, const QPixmap &pm = QPixmap(),
@@ -235,18 +235,18 @@ public:
     void setDrawParams(DrawParams *);
 
     // draw on a given QPainter, use this class as info provider per default
-    void drawBack(QPainter *, DrawParams *dp = 0);
+    void drawBack(QPainter *, DrawParams *dp = nullptr);
     /* Draw field at position() from pixmap()/text() with maxLines().
      * Returns true if something was drawn
      */
-    bool drawField(QPainter *, int f, DrawParams *dp = 0);
+    bool drawField(QPainter *, int f, DrawParams *dp = nullptr);
 
     // resets rectangle for free space
     void setRect(const QRect &);
 
     // Returns the rectangle area still free of text/pixmaps after
     // a number of drawText() calls.
-    QRect remainingRect(DrawParams *dp = 0);
+    QRect remainingRect(DrawParams *dp = nullptr);
 
 private:
     int _usedTopLeft, _usedTopCenter, _usedTopRight;
@@ -298,11 +298,11 @@ public:
                      Horizontal, Vertical
                    };
 
-    explicit TreeMapItem(TreeMapItem *parent = Q_NULLPTR, double value = 1.0);
+    explicit TreeMapItem(TreeMapItem *parent = nullptr, double value = 1.0);
     TreeMapItem(TreeMapItem *parent, double value,
                 const QString &text1, const QString &text2 = QString(),
                 const QString &text3 = QString(), const QString &text4 = QString());
-    virtual ~TreeMapItem();
+    ~TreeMapItem() override;
 
     bool isChildOf(TreeMapItem *);
 
@@ -418,8 +418,8 @@ public:
     virtual double sum() const;
     virtual double value() const;
     // replace "Default" position with setting from TreeMapWidget
-    Position position(int) const Q_DECL_OVERRIDE;
-    const QFont &font() const Q_DECL_OVERRIDE;
+    Position position(int) const override;
+    const QFont &font() const override;
     virtual bool isMarked(int) const;
 
     virtual int borderWidth() const;
@@ -496,8 +496,8 @@ public:
     enum SelectionMode { Single, Multi, Extended, NoSelection };
 
     /* The widget gets owner of the base item */
-    explicit TreeMapWidget(TreeMapItem *base, QWidget *parent = Q_NULLPTR);
-    ~TreeMapWidget();
+    explicit TreeMapWidget(TreeMapItem *base, QWidget *parent = nullptr);
+    ~TreeMapWidget() override;
 
     /**
      * Returns the TreeMapItem filling out the widget space
@@ -554,7 +554,7 @@ public:
      * parent. When parent == 0, clears whole selection
      * Returns true if selection changed.
      */
-    bool clearSelection(TreeMapItem *parent = Q_NULLPTR);
+    bool clearSelection(TreeMapItem *parent = nullptr);
 
     /**
      * Selects or unselects items in a range.
@@ -825,15 +825,15 @@ signals:
     void contextMenuRequested(TreeMapItem *, const QPoint &);
 
 protected:
-    void mousePressEvent(QMouseEvent *) Q_DECL_OVERRIDE;
-    void contextMenuEvent(QContextMenuEvent *) Q_DECL_OVERRIDE;
-    void mouseReleaseEvent(QMouseEvent *) Q_DECL_OVERRIDE;
-    void mouseMoveEvent(QMouseEvent *) Q_DECL_OVERRIDE;
-    void mouseDoubleClickEvent(QMouseEvent *) Q_DECL_OVERRIDE;
-    void keyPressEvent(QKeyEvent *) Q_DECL_OVERRIDE;
-    void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
+    void mousePressEvent(QMouseEvent *) override;
+    void contextMenuEvent(QContextMenuEvent *) override;
+    void mouseReleaseEvent(QMouseEvent *) override;
+    void mouseMoveEvent(QMouseEvent *) override;
+    void mouseDoubleClickEvent(QMouseEvent *) override;
+    void keyPressEvent(QKeyEvent *) override;
+    void paintEvent(QPaintEvent *) override;
     void fontChange(const QFont &);
-    bool event(QEvent *event) Q_DECL_OVERRIDE;
+    bool event(QEvent *event) override;
     // For "Esc deselects all" functionality implemented in FSView.
     TreeMapItem *_pressed;
     // add a checkable popup item
