@@ -49,6 +49,9 @@ private:
     QCheckBox *m_pDoNotTrack;
     QCheckBox *m_pOfferToSaveWebsitePassword;
     KIntNumInput *m_pMaxFormCompletionItems;
+#ifdef WEBENGINE_PDF_VIEWER
+    QCheckBox *m_pdfViewer;
+#endif
 };
 
 #endif // HTMLOPTS_H
