@@ -43,7 +43,7 @@
 
 // == class JavaPolicies =====
 
-JavaPolicies::JavaPolicies(KSharedConfig::Ptr config, const QString &group, bool global,
+JavaPolicies::JavaPolicies(const KSharedConfig::Ptr &config, const QString &group, bool global,
                            const QString &domain) :
     Policies(config, group, global, domain, QStringLiteral("java."), QStringLiteral("EnableJava"))
 {
@@ -61,7 +61,7 @@ JavaPolicies::~JavaPolicies()
 
 // == class KJavaOptions =====
 
-KJavaOptions::KJavaOptions(KSharedConfig::Ptr config, const QString &group,
+KJavaOptions::KJavaOptions(const KSharedConfig::Ptr &config, const QString &group,
                            QWidget *parent)
     : KCModule(parent),
       _removeJavaScriptDomainAdvice(false),
@@ -107,7 +107,7 @@ KJavaOptions::KJavaOptions(KSharedConfig::Ptr config, const QString &group,
     connect(enableShutdownCB, &QAbstractButton::clicked, this, &KJavaOptions::toggleJavaControls);
     QWidget *secondsHB = new QWidget(javartGB);
     QHBoxLayout *secondsHBHBoxLayout = new QHBoxLayout(secondsHB);
-    secondsHBHBoxLayout->setMargin(0);
+    secondsHBHBoxLayout->setContentsMargins(0, 0, 0, 0);
     laygroup1->addWidget(secondsHB);
     serverTimeoutSB = new KIntNumInput(secondsHB);
     secondsHBHBoxLayout->addWidget(serverTimeoutSB);
