@@ -30,7 +30,7 @@ public:
     Konqueror_ui(QWidget *parent) : QWidget(parent)
     {
         setupUi(this);
-        layout()->setMargin(0);
+        layout()->setContentsMargins(0, 0, 0, 0);
     }
 };
 
@@ -39,7 +39,7 @@ class Konqueror
 {
     Q_OBJECT
 public:
-    Konqueror(QWidget *parent_P = NULL);
+    Konqueror(QWidget *parent_P = nullptr);
     void load();
     void save();
     void defaults();
