@@ -140,7 +140,7 @@ void KonqHistoryManager::addToHistory(bool pending, const QUrl &_url,
         // If there is no entry for the url yet, we just store the url.
         KonqHistoryList::const_iterator oldEntry = constFindEntry(url);
         m_pending.insert(u, (oldEntry != entries().constEnd()) ?
-                         new KonqHistoryEntry(*oldEntry) : 0);
+                         new KonqHistoryEntry(*oldEntry) : nullptr);
     }
 
     // notify all konqueror instances about the entry
@@ -262,7 +262,7 @@ void KonqHistoryManager::finishAddingEntry(const KonqHistoryEntry &entry, bool i
 
     // note, no need to do the updateBookmarkMetadata for every
     // history object, only need to for the broadcast sender as
-    // the history object itself keeps the data consistant.
+    // the history object itself keeps the data consistent.
     // ### why does the comment do exactly the opposite from the code?
     const bool updated = m_bookmarkManager ? m_bookmarkManager->updateAccessMetadata(urlString) : false;
 
