@@ -26,28 +26,29 @@
 #include "ui_konqnewsessiondlg_base.h"
 
 #include <QDir>
-#include <QFileInfo>
 #include <QDirIterator>
+#include <QFileInfo>
+#include <QIcon>
 #include <QPushButton>
+#include <QStandardPaths>
 
 #include "konqdebug.h"
 #include <kio/copyjob.h>
-#include <ktempdir.h>
 #include <kio/renamedialog.h>
 #include <kfileitemdelegate.h>
-#include <QIcon>
 #include <kdirlister.h>
 #include <kdirmodel.h>
 #include <kstandardguiitem.h>
 #include <kio/global.h>
-#include <kstandarddirs.h>
 #include <KLocalizedString>
 #include <kconfig.h>
 #include <kseparator.h>
 #include <kmessagebox.h>
-#include <kdialog.h>
-#include <klistwidget.h>
-#include <QStandardPaths>
+#include <QDialog>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <KGuiItem>
+#include <QVBoxLayout>
 
 class KonqSessionDlg::KonqSessionDlgPrivate : public QWidget,
     public Ui::KonqSessionDlgBase
@@ -61,30 +62,26 @@ public:
     KonqViewManager *const m_pViewManager;
     KDirModel *m_pModel;
     QWidget *m_pParent;
+    QDialogButtonBox *m_buttonBox;
 };
 
-#define BTN_OPEN KDialog::User1
-
 KonqSessionDlg::KonqSessionDlg(KonqViewManager *manager, QWidget *parent)
-    : KDialog(parent)
+    : QDialog(parent)
     , d(new KonqSessionDlgPrivate(manager, this))
 {
-    d->layout()->setContentsMargins(0, 0, 0, 0);
-    setMainWidget(d);
-
     setObjectName(QStringLiteral("konq_session_dialog"));
     setModal(true);
-    setCaption(i18nc("@title:window", "Manage Sessions"));
-    setButtons(BTN_OPEN | Close);
-    setDefaultButton(Close);
+    setWindowTitle(i18nc("@title:window", "Manage Sessions"));
+
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    mainLayout->addWidget(d);
 
-    setButtonGuiItem(BTN_OPEN, KGuiItem(i18n("&Open"), QStringLiteral("document-open")));
     d->m_pSaveCurrentButton->setIcon(QIcon::fromTheme(QStringLiteral("document-save")));
     d->m_pRenameButton->setIcon(QIcon::fromTheme(QStringLiteral("edit-rename")));
     d->m_pDeleteButton->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
     d->m_pNewButton->setIcon(QIcon::fromTheme(QStringLiteral("document-new")));
 
-    QString dir = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + QLatin1String("sessions/");
+    QString dir = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1String("/sessions/");
     QDir().mkpath(dir);
 
     d->m_pModel = new KDirModel(d->m_pListView);
@@ -99,19 +96,24 @@ KonqSessionDlg::KonqSessionDlg(KonqViewManager *manager, QWidget *parent)
                 const QItemSelection &, const QItemSelection &)), this, SLOT(
                 slotSelectionChanged()));
 
-    enableButton(BTN_OPEN, d->m_pListView->currentIndex().isValid());
-    slotSelectionChanged();
-
     d->m_pOpenTabsInsideCurrentWindow->setChecked(
         KonqSettings::openTabsInsideCurrentWindow());
 
-    connect(this, &KonqSessionDlg::user1Clicked, this, &KonqSessionDlg::slotOpen);
     connect(d->m_pNewButton, &QPushButton::clicked, this, &KonqSessionDlg::slotNew);
     connect(d->m_pSaveCurrentButton, &QPushButton::clicked, this, &KonqSessionDlg::slotSave);
     connect(d->m_pRenameButton, SIGNAL(clicked()), SLOT(slotRename()));
     connect(d->m_pDeleteButton, &QPushButton::clicked, this, &KonqSessionDlg::slotDelete);
 
-    resize(sizeHint());
+    d->m_buttonBox = new QDialogButtonBox(QDialogButtonBox::Open | QDialogButtonBox::Close);
+    connect(d->m_buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+    connect(d->m_buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+    mainLayout->addWidget(d->m_buttonBox);
+    d->m_buttonBox->button(QDialogButtonBox::Close)->setDefault(true);
+    QPushButton *openButton = d->m_buttonBox->button(QDialogButtonBox::Open);
+    connect(openButton, &QPushButton::clicked, this, &KonqSessionDlg::slotOpen);
+
+    slotSelectionChanged();
+
 }
 
 KonqSessionDlg::~KonqSessionDlg()
@@ -161,7 +163,7 @@ void KonqSessionDlg::slotDelete()
     }
 
     const QString dir = d->m_pModel->itemForIndex(d->m_pListView->currentIndex()).url().toLocalFile();
-    if (!KTempDir::removeDir(dir)) {
+    if (!QDir(dir).removeRecursively()) {
         // TODO show error msg box
     }
 }
@@ -186,7 +188,7 @@ void KonqSessionDlg::slotRename(QUrl dirpathTo)
         if (dir.exists()) {
             slotRename(dirpathTo);
         } else {
-            QDir dir(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "sessions/");
+            QDir dir(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1String("/sessions/"));
             dir.rename(dirpathFrom.fileName(), dlg.newDestUrl().fileName());
         }
     }
@@ -198,11 +200,10 @@ void KonqSessionDlg::slotSelectionChanged()
     d->m_pSaveCurrentButton->setEnabled(enable);
     d->m_pRenameButton->setEnabled(enable);
     d->m_pDeleteButton->setEnabled(enable);
-    enableButton(BTN_OPEN, enable);
+    QPushButton *openButton = d->m_buttonBox->button(QDialogButtonBox::Open);
+    openButton->setEnabled(enable);
 }
 
-#undef BTN_OPEN
-
 class KonqNewSessionDlg::KonqNewSessionDlgPrivate : public QWidget,
     public Ui::KonqNewSessionDlgBase
 {
@@ -216,40 +217,46 @@ public:
     QWidget *m_pParent;
     KonqMainWindow *m_mainWindow;
     KonqNewSessionDlg::Mode m_mode;
+    QDialogButtonBox *m_buttonBox;
 };
 
 KonqNewSessionDlg::KonqNewSessionDlg(QWidget *parent, KonqMainWindow *mainWindow, QString sessionName, Mode mode)
-    : KDialog(parent)
+    : QDialog(parent)
     , d(new KonqNewSessionDlgPrivate(this, mainWindow, mode))
 {
-    d->layout()->setContentsMargins(0, 0, 0, 0);
-    setMainWidget(d);
-
     setObjectName(QStringLiteral("konq_new_session_dialog"));
     setModal(true);
-    setCaption(i18nc("@title:window", "Save Session"));
-    setButtons(Ok | Cancel);
-    setDefaultButton(Ok);
-    enableButton(Ok, false);
+    setWindowTitle(i18nc("@title:window", "Save Session"));
+
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    mainLayout->addWidget(d);
+
+    d->m_buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    mainLayout->addWidget(d->m_buttonBox);
+    QPushButton *okButton = d->m_buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    okButton->setEnabled(false);
 
     if (!sessionName.isEmpty()) {
         d->m_pSessionName->setText(sessionName);
-        enableButton(Ok, true);
+        okButton->setEnabled(true);
     }
 
     d->m_pSessionName->setFocus();
 
-    connect(this, &KonqNewSessionDlg::okClicked, this, &KonqNewSessionDlg::slotAddSession);
+    connect(okButton, &QPushButton::clicked, this, &KonqNewSessionDlg::slotAddSession);
     connect(d->m_pSessionName, SIGNAL(textChanged(QString)), this,
             SLOT(slotTextChanged(QString)));
 
     resize(sizeHint());
+    connect(d->m_buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+    connect(d->m_buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 }
 
 void KonqNewSessionDlg::slotAddSession()
 {
-    QString dirpath = KStandardDirs::locateLocal("appdata", "sessions/" +
-                      KIO::encodeFileName(d->m_pSessionName->text()));
+    QString dirpath = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1String("/sessions/") + KIO::encodeFileName(d->m_pSessionName->text());
 
     QDir dir(dirpath);
     if (dir.exists()) {
@@ -257,7 +264,7 @@ void KonqNewSessionDlg::slotAddSession()
             KMessageBox::questionYesNo(this,
                                        i18n("A session with the name '%1' already exists, do you want to overwrite it?", d->m_pSessionName->text()),
                                        i18nc("@title:window", "Session exists. Overwrite?")) == KMessageBox::Yes) {
-            KTempDir::removeDir(dirpath);
+            QDir(dirpath).removeRecursively();
         } else {
             return;
         }
@@ -272,7 +279,8 @@ void KonqNewSessionDlg::slotAddSession()
 
 void KonqNewSessionDlg::slotTextChanged(const QString &text)
 {
-    enableButton(Ok, !text.isEmpty());
+    QPushButton *okButton = d->m_buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setEnabled(!text.isEmpty());
 }
 
 KonqNewSessionDlg::~KonqNewSessionDlg()
