@@ -41,7 +41,6 @@
 #include <ktoggleaction.h>
 #include <kjobuidelegate.h>
 #include <KUrlMimeData>
-#include <KComponentData>
 
 #include <QApplication>
 #include <QArgument>
@@ -65,6 +64,8 @@
 #include <KParts/OpenUrlArguments>
 #include <KParts/BrowserExtension>
 #include <KParts/WindowArgs>
+#include <QMimeDatabase>
+#include <QMimeType>
 
 //#define DEBUG_HISTORY
 
@@ -1188,7 +1189,7 @@ bool KonqView::eventFilter(QObject *obj, QEvent *e)
         if (mimeData->hasUrls()) {
             QList<QUrl> lstDragURLs = KUrlMimeData::urlsFromMimeData(mimeData);
 
-            QList<QObject *> children = qFindChildren<QObject *>(m_pPart->widget());   // ### slow, better write a isChildOf with a loop...
+            const QList<QObject *> children = m_pPart->widget()->findChildren<QObject *>();   // ### slow, better write a isChildOf with a loop...
 
             if (!lstDragURLs.isEmpty()
                     && !lstDragURLs.first().url().startsWith(QLatin1String("javascript:"), Qt::CaseInsensitive) &&   // ### this looks like a hack to me
@@ -1273,20 +1274,22 @@ KParts::StatusBarExtension *KonqView::statusBarExtension() const
     return KParts::StatusBarExtension::childObject(m_pPart);
 }
 
-KMimeType::Ptr KonqView::mimeType() const
+QMimeType KonqView::mimeType() const
 {
-    return KMimeType::mimeType(serviceType()); // can be null
+    QMimeDatabase db;
+    return db.mimeTypeForName(serviceType());
 }
 
 bool KonqView::supportsMimeType(const QString &mimeType) const
 {
-    KMimeType::Ptr mime = KMimeType::mimeType(mimeType, KMimeType::ResolveAliases);
-    if (!mime) {
+    QMimeDatabase db;
+    QMimeType mime = db.mimeTypeForName(mimeType);
+    if (!mime.isValid()) {
         return false;
     }
     const QStringList lst = serviceTypes();
     for (QStringList::ConstIterator it = lst.begin(); it != lst.end(); ++it) {
-        if (mime->is(*it)) { // same as mime == *it, but also respect inheritance, mimeType can be a subclass
+        if (mime.inherits(*it)) { // same as mime == *it, but also respect inheritance, mimeType can be a subclass
             return true;
         }
     }
