@@ -25,6 +25,8 @@
 #include "webengineview.h"
 #include "webenginepage.h"
 #include "settings/webenginesettings.h"
+#include <webenginepart_debug.h>
+
 #include <QWebEngineSettings>
 
 #include <KDesktopFile>
@@ -73,12 +75,12 @@ InvokeWrapper<Arg, R, C> invoke(R *receiver, void (C::*memberFun)(Arg))
 WebEngineBrowserExtension::WebEngineBrowserExtension(WebEnginePart *parent, const QByteArray& cachedHistoryData)
                        :KParts::BrowserExtension(parent),
                         m_part(parent),
-                        mCurrentPrinter(Q_NULLPTR)
+                        mCurrentPrinter(nullptr)
 {
-    enableAction("cut", false);
-    enableAction("copy", false);
-    enableAction("paste", false);
-    enableAction("print", true);
+    emit enableAction("cut", false);
+    emit enableAction("copy", false);
+    emit enableAction("paste", false);
+    emit enableAction("print", true);
 
     if (cachedHistoryData.isEmpty()) {
         return;
@@ -135,7 +137,7 @@ int WebEngineBrowserExtension::yOffset()
 void WebEngineBrowserExtension::saveState(QDataStream &stream)
 {
     // TODO: Save information such as form data from the current page.
-    QWebEngineHistory* history = (view() ? view()->history() : 0);
+    QWebEngineHistory* history = (view() ? view()->history() : nullptr);
     const int historyIndex = (history ? history->currentItemIndex() : -1);
     const QUrl historyUrl = (history && historyIndex > -1) ? QUrl(history->currentItem().url()) : m_part->url();
 
@@ -153,7 +155,7 @@ void WebEngineBrowserExtension::restoreState(QDataStream &stream)
     qint32 xOfs = -1, yOfs = -1, historyItemIndex = -1;
     stream >> u >> xOfs >> yOfs >> historyItemIndex >> historyData;
 
-    QWebEngineHistory* history = (view() ? view()->page()->history() : 0);
+    QWebEngineHistory* history = (view() ? view()->page()->history() : nullptr);
     if (history) {
         bool success = false;
         if (history->count() == 0) {   // Handle restoration: crash recovery, tab close undo, session restore
@@ -210,7 +212,7 @@ void WebEngineBrowserExtension::restoreState(QDataStream &stream)
 
     // As a last resort, in case the history restoration logic above fails,
     // attempt to open the requested URL directly.
-    qDebug() << "Normal history navigation logic failed! Falling back to opening url directly.";
+    qCDebug(WEBENGINEPART_LOG) << "Normal history navigation logic failed! Falling back to opening url directly.";
     m_part->openUrl(u);
 }
 
@@ -250,7 +252,7 @@ void WebEngineBrowserExtension::print()
 #if QTWEBENGINE_VERSION >= QT_VERSION_CHECK(5, 8, 0)
     if (view()) {
         mCurrentPrinter = new QPrinter();
-        QPointer<QPrintDialog> dialog = new QPrintDialog(mCurrentPrinter, Q_NULLPTR);
+        QPointer<QPrintDialog> dialog = new QPrintDialog(mCurrentPrinter, nullptr);
         dialog->setWindowTitle(i18n("Print Document"));
         if (dialog->exec() != QDialog::Accepted) {
             slotHandlePagePrinted(false);
@@ -267,7 +269,7 @@ void WebEngineBrowserExtension::slotHandlePagePrinted(bool result)
 {
     Q_UNUSED(result);
     delete mCurrentPrinter;
-    mCurrentPrinter = Q_NULLPTR;
+    mCurrentPrinter = nullptr;
 }
 
 
@@ -276,16 +278,16 @@ void WebEngineBrowserExtension::updateEditActions()
     if (!view())
         return;
 
-    enableAction("cut", view()->pageAction(QWebEnginePage::Cut)->isEnabled());
-    enableAction("copy", view()->pageAction(QWebEnginePage::Copy)->isEnabled());
-    enableAction("paste", view()->pageAction(QWebEnginePage::Paste)->isEnabled());
+    emit enableAction("cut", view()->pageAction(QWebEnginePage::Cut)->isEnabled());
+    emit enableAction("copy", view()->pageAction(QWebEnginePage::Copy)->isEnabled());
+    emit enableAction("paste", view()->pageAction(QWebEnginePage::Paste)->isEnabled());
 }
 
 void WebEngineBrowserExtension::updateActions()
 {
     const QString protocol (m_part->url().scheme());
     const bool isValidDocument = (protocol != QL1S("about") && protocol != QL1S("error"));
-    enableAction("print", isValidDocument);
+    emit enableAction("print", isValidDocument);
 }
 
 void WebEngineBrowserExtension::searchProvider()
@@ -323,7 +325,7 @@ void WebEngineBrowserExtension::reparseConfiguration()
 void WebEngineBrowserExtension::disableScrolling()
 {
     QWebEngineView* currentView = view();
-    QWebEnginePage* page = currentView ? currentView->page() : 0;
+    QWebEnginePage* page = currentView ? currentView->page() : nullptr;
 
     if (!page)
         return;
@@ -538,7 +540,7 @@ void WebEngineBrowserExtension::slotViewDocumentSource()
 
     const QUrl pageUrl (view()->url());
     if (pageUrl.isLocalFile()) {
-        KRun::runUrl(pageUrl, QL1S("text/plain"), view(), false);
+        KRun::runUrl(pageUrl, QL1S("text/plain"), view(), KRun::RunFlags());
     } else {
         view()->page()->toHtml([this](const QString& html) {
             QTemporaryFile tempFile;
@@ -546,7 +548,7 @@ void WebEngineBrowserExtension::slotViewDocumentSource()
             tempFile.setAutoRemove(false);
             if (tempFile.open()) {
                 tempFile.write(html.toUtf8());
-                KRun::runUrl(QUrl::fromLocalFile(tempFile.fileName()), QL1S("text/plain"), view(), true, false);
+                KRun::runUrl(QUrl::fromLocalFile(tempFile.fileName()), QL1S("text/plain"), view(), KRun::RunFlags(KRun::DeleteTemporaryFiles));
             }
         });
     }
@@ -781,7 +783,7 @@ void WebEngineBrowserExtension::slotSpellCheckDone(const QString&)
 
 void WebEngineBrowserExtension::saveHistory()
 {
-    QWebEngineHistory* history = (view() ? view()->history() : 0);
+    QWebEngineHistory* history = (view() ? view()->history() : nullptr);
 
     if (history && history->count() > 0) {
         //kDebug() << "Current history: index=" << history->currentItemIndex() << "url=" << history->currentItem().url();
@@ -793,8 +795,8 @@ void WebEngineBrowserExtension::saveHistory()
             stream << *history;
             m_historyData = qCompress(histData, 9);
         }
-        QWidget* mainWidget = m_part ? m_part->widget() : 0;
-        QWidget* frameWidget = mainWidget ? mainWidget->parentWidget() : 0;
+        QWidget* mainWidget = m_part ? m_part->widget() : nullptr;
+        QWidget* frameWidget = mainWidget ? mainWidget->parentWidget() : nullptr;
         if (frameWidget) {
             emit saveHistory(frameWidget, m_historyData);
             // kDebug() << "# of items:" << history->count() << "current item:" << history->currentItemIndex() << "url:" << history->currentItem().url();
@@ -1046,9 +1048,9 @@ QList<KParts::SelectorInterface::Element> WebEngineHtmlExtension::querySelectorA
 
 QVariant WebEngineHtmlExtension::htmlSettingsProperty(KParts::HtmlSettingsInterface::HtmlSettingsType type) const
 {
-    QWebEngineView* view = part() ? part()->view() : 0;
-    QWebEnginePage* page = view ? view->page() : 0;
-    QWebEngineSettings* settings = page ? page->settings() : 0;
+    QWebEngineView* view = part() ? part()->view() : nullptr;
+    QWebEnginePage* page = view ? view->page() : nullptr;
+    QWebEngineSettings* settings = page ? page->settings() : nullptr;
 
     if (settings) {
         switch (type) {
@@ -1084,9 +1086,9 @@ QVariant WebEngineHtmlExtension::htmlSettingsProperty(KParts::HtmlSettingsInterf
 
 bool WebEngineHtmlExtension::setHtmlSettingsProperty(KParts::HtmlSettingsInterface::HtmlSettingsType type, const QVariant& value)
 {
-    QWebEngineView* view = part() ? part()->view() : 0;
-    QWebEnginePage* page = view ? view->page() : 0;
-    QWebEngineSettings* settings = page ? page->settings() : 0;
+    QWebEngineView* view = part() ? part()->view() : nullptr;
+    QWebEnginePage* page = view ? view->page() : nullptr;
+    QWebEngineSettings* settings = page ? page->settings() : nullptr;
 
     if (settings) {
         switch (type) {
@@ -1155,7 +1157,7 @@ bool WebEngineScriptableExtension::setException (KParts::ScriptableExtension* ca
 QVariant WebEngineScriptableExtension::get (KParts::ScriptableExtension* callerPrincipal, quint64 objId, const QString& propName)
 {
     //kDebug() << "caller:" << callerPrincipal << "id:" << objId << "propName:" << propName;
-    return callerPrincipal->get (0, objId, propName);
+    return callerPrincipal->get (nullptr, objId, propName);
 }
 
 bool WebEngineScriptableExtension::put (KParts::ScriptableExtension* callerPrincipal, quint64 objId, const QString& propName, const QVariant& value)
@@ -1165,7 +1167,7 @@ bool WebEngineScriptableExtension::put (KParts::ScriptableExtension* callerPrinc
 
 static QVariant exception(const char* msg)
 {
-    qWarning() << msg;
+    qCWarning(WEBENGINEPART_LOG) << msg;
     return QVariant::fromValue(KParts::ScriptableExtension::Exception(QString::fromLatin1(msg)));
 }
 
@@ -1182,7 +1184,7 @@ QVariant WebEngineScriptableExtension::evaluateScript (KParts::ScriptableExtensi
         return exception("unsupported language");
 
 
-    KParts::ReadOnlyPart* part = callerPrincipal ? qobject_cast<KParts::ReadOnlyPart*>(callerPrincipal->parent()) : 0;
+    KParts::ReadOnlyPart* part = callerPrincipal ? qobject_cast<KParts::ReadOnlyPart*>(callerPrincipal->parent()) : nullptr;
    // QWebFrame* frame = part ? qobject_cast<QWebFrame*>(part->parent()) : 0;
    // if (!frame)
         return exception("failed to resolve principal");
